import { Component, OnInit, ViewEncapsulation } from '@angular/core';

import { Router } from '@angular/router';

import { EmptyStateConfig } from 'patternfly-ng/empty-state';

import { Action, ActionConfig } from 'patternfly-ng/action';

@Component({
    encapsulation: ViewEncapsulation.None,
    selector: 'app-access-denied',
    templateUrl: './access-denied.component.html',
    styleUrls: ['./access-denied.component.less'],
})
export class AccessDeniedComponent implements OnInit {
    // Used to track which component is being loaded
    componentName = 'AccessDeniedComponent';

    constructor(private router: Router) {}

    pageTitle = 'Access Denied';
    pageIcon = 'fa fa-exclamation-triangle';
    actionConfig: ActionConfig;
    emptyStateConfig: EmptyStateConfig;

    ngOnInit(): void {
        this.actionConfig = {
            primaryActions: [
                {
                    id: 'home',
                    title: 'Home',
                    tooltip: 'View the home page',
                },
            ],
        } as ActionConfig;

        this.emptyStateConfig = {
            actions: this.actionConfig,
            iconStyleClass: 'fa fa-frown-o',
            info:
                'You do not have access to the requested page. Choose one of the navigation options on the left, ' +
                'or click the Home button below, to visit the home page',
            title: 'Access Denied',
        } as EmptyStateConfig;
    }

    handleActionClicked($event: Action) {
        this.router.navigate(['/home']);
    }
}
